/// <reference types="node" />
import { Key } from './key';
export interface Obj<T> {
    readonly e: string[];
    readonly h: string;
}
export interface ValueType<T, H = Obj<T>> {
    readonly name: string;
    readonly type: string;
    key?: Key;
    set(t: T): T;
    get(): T;
    setKleisimo(t: H): T;
    getKleisimo(): H;
}
export declare class AttributeRegister<O, H> {
    readonly attributes: ValueType<unknown, unknown>[];
    register<T, H>(vt: ValueType<T, H>): void;
    asUnencrypted(): O;
    asEncrypted(): H;
}
export declare class Attribute<T> implements ValueType<T> {
    readonly name: string;
    readonly type: string;
    key: Key;
    value: T;
    constructor(ar: AttributeRegister<unknown, unknown>, name: string, type: string, key: Key);
    set(t: T): T;
    get(): T;
    unpad(b: string): string;
    setKleisimo(t: Obj<T>): T;
    pad(p: string): Buffer;
    getKleisimo(): Obj<T>;
}
export interface DateObj {
    month: number;
    year: number;
    encrypted: string;
}
export declare class DateAttribute implements ValueType<Date, DateObj> {
    readonly name: string;
    readonly type: string;
    key: Key;
    value: Date;
    constructor(ar: AttributeRegister<unknown, unknown>, name: string, key: Key);
    get(): Date;
    setKleisimo(t: DateObj): Date;
    getKleisimo(): DateObj;
    set(t: Date): Date;
}
export interface ZipObj {
    readonly zip: string;
}
export declare class ZipAttribute implements ValueType<string, ZipObj> {
    readonly name: string;
    readonly type: string;
    key: Key;
    value: string;
    constructor(ar: AttributeRegister<unknown, unknown>, name: string, key: Key);
    get(): string;
    setKleisimo(t: ZipObj): string;
    getKleisimo(): ZipObj;
    set(t: string): string;
}
export declare class OpenAttribute<T> implements ValueType<T, T> {
    readonly name: string;
    readonly type: string;
    value: T;
    constructor(ar: AttributeRegister<unknown, unknown>, name: string, type: string);
    key?: Key | undefined;
    set(t: T): T;
    get(): T;
    getKleisimo(): T;
    setKleisimo(t: T): T;
}
